==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ChangeDataCaptureFolderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The folder that this CDC is in. If not specified, CDC will appear at the root level.
 * @property name The name of the folder that this CDC is in.
 */
public data class ChangeDataCaptureFolderArgs(
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs =
        com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChangeDataCaptureFolderArgs].
 */
@PulumiTagMarker
public class ChangeDataCaptureFolderArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value The name of the folder that this CDC is in.
     */
    @JvmName("bgyhivdilyytifkb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The name of the folder that this CDC is in.
     */
    @JvmName("xfayylcjcmjxtkss")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ChangeDataCaptureFolderArgs = ChangeDataCaptureFolderArgs(
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ChangeDataCaptureFolderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The folder that this CDC is in. If not specified, CDC will appear at the root level.
 * @property name The name of the folder that this CDC is in.
 */
public data class ChangeDataCaptureFolderArgs(
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs =
        com.pulumi.azurenative.datafactory.inputs.ChangeDataCaptureFolderArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChangeDataCaptureFolderArgs].
 */
@PulumiTagMarker
public class ChangeDataCaptureFolderArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value The name of the folder that this CDC is in.
     */
    @JvmName("rtlvcfaodspgruip")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The name of the folder that this CDC is in.
     */
    @JvmName("jhxxmggmfsmcseyu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ChangeDataCaptureFolderArgs = ChangeDataCaptureFolderArgs(
        name = name,
    )
}
